@@ -221,7 +221,6 @@ class Store(StorageInterface):
         revision = self._tiddler_revision_filename(tiddler) + 1
         tiddler_filename = self._tiddler_full_filename(tiddler, revision)
 
-        self.serializer.object = tiddler
         representation = self.serializer.serialization.tiddler_as(tiddler,
                 omit_empty=True, omit_members=['creator'])
         write_utf8_file(tiddler_filename, representation)
@@ -512,7 +511,7 @@ class Store(StorageInterface):
         try:
             revision = int(revision)
         except ValueError, exc:
-            raise NoTiddlerError('%s is not a valid revision id' % exc)
+            raise NoTiddlerError('%s is not a valid revision id' % revision)
 
         return revision
 
@@ -552,4 +551,4 @@ def _encode_filename(filename):
 
     if not filename or '../' in filename:
         raise StoreEncodingError('invalid name for entity')
-    return urllib.quote(filename.encode('utf-8'), safe='')
+    return urllib.quote(filename.encode('utf-8'), safe=".!~*'()")
